from enum import Enum


class UpdateProjectSettingsMultipartDataChatbotMsgLang(str, Enum):
    AR = "ar"
    AZ = "az"
    BA = "ba"
    BE = "be"
    BG = "bg"
    BH = "bh"
    BN = "bn"
    BS = "bs"
    CA = "ca"
    CMN = "cmn"
    CS = "cs"
    CY = "cy"
    DA = "da"
    DE = "de"
    DOI = "doi"
    EL = "el"
    EN = "en"
    ES = "es"
    ET = "et"
    EU = "eu"
    FA = "fa"
    FI = "fi"
    FO = "fo"
    FR = "fr"
    GA = "ga"
    GL = "gl"
    GU = "gu"
    HE = "he"
    HI = "hi"
    HNE = "hne"
    HR = "hr"
    HRY = "hry"
    HU = "hu"
    HY = "hy"
    ID = "id"
    IT = "it"
    JA = "ja"
    JV = "jv"
    KA = "ka"
    KK = "kk"
    KN = "kn"
    KO = "ko"
    KOK = "kok"
    KS = "ks"
    KY = "ky"
    LT = "lt"
    LV = "lv"
    MAI = "mai"
    ME = "me"
    MK = "mk"
    MN = "mn"
    MO = "mo"
    MR = "mr"
    MS = "ms"
    MT = "mt"
    MWR = "mwr"
    NAN = "nan"
    NE = "ne"
    NL = "nl"
    NO = "no"
    OR = "or"
    PA = "pa"
    PL = "pl"
    PS = "ps"
    PT = "pt"
    PT_BR = "pt-BR"
    RAJ = "raj"
    RO = "ro"
    RU = "ru"
    SA = "sa"
    SAT = "sat"
    SD = "sd"
    SI = "si"
    SK = "sk"
    SL = "sl"
    SQ = "sq"
    SR = "sr"
    SV = "sv"
    SW = "sw"
    TA = "ta"
    TE = "te"
    TG = "tg"
    TH = "th"
    TK = "tk"
    TR = "tr"
    TT = "tt"
    UK = "uk"
    UR = "ur"
    UZ = "uz"
    VI = "vi"
    WUU = "wuu"
    YUE = "yue"

    def __str__(self) -> str:
        return str(self.value)
